Networks
========

Networks are dividied depending on their context.
For some reason it's often to find convetion of heads and bodies, and that's why we're keeping it here.
If you haven't heard of these before think about the Frankeinstain monster.
Body is not a whole body but rather a body part, e.g. arms and legs.
Obviously(!), they don't work by themselves so you need a head which will control them.
Some heads take body parts explicitly and build the whole monstrocity and some heads are predefined
to closely match suggestion in a paper. So, in general, a head is more complex and does more than a body,
but for some agents a single body part, e.g. Fully connected network, is good enough.


Bodies
------

.. automodule:: ai_traineree.networks.bodies
    :members:
    :undoc-members:

Heads
-----

.. automodule:: ai_traineree.networks.heads
    :members:
    :undoc-members:
